@@ -26,7 +26,7 @@
 #       You may only use this script to uninstall the version
 #       shown below. Simply run this script to remove Shorewall Firewall
 
-VERSION=4.6.5.4
+VERSION=4.6.8
 PRODUCT=shorewall6
 
 usage() # $1 = exit status
@@ -36,6 +36,12 @@ usage() # $1 = exit status
     exit $1
 }
 
+fatal_error()
+{
+    echo "   ERROR: $@" >&2
+    exit 1
+}
+
 qt()
 {
     "$@" >/dev/null 2>&1
@@ -136,8 +142,8 @@ else
     usage 1
 fi
 
-if [ -f ${SHARDIR}/shorewall6/version ]; then
-    INSTALLED_VERSION="$(cat /usr/share/shorewall6/version)"
+if [ -f ${SHAREDIR}/shorewall6/version ]; then
+    INSTALLED_VERSION="$(cat ${SHAREDIR}/shorewall6/version)"
     if [ "$INSTALLED_VERSION" != "$VERSION" ]; then
 	echo "WARNING: Shorewall6 Version $INSTALLED_VERSION is installed"
 	echo "         and this is the $VERSION uninstaller."
